Struct WpColorManagementSurfaceV1
pub struct WpColorManagementSurfaceV1 { /* private fields */ }wayland and Linux only.Expand description
color management extension to a surface
A wp_color_management_surface_v1 allows the client to set the color space and HDR properties of a surface.
If the wl_surface associated with the wp_color_management_surface_v1 is destroyed, the wp_color_management_surface_v1 object becomes inert.
This interface has no events.
Implementations
impl WpColorManagementSurfaceV1
impl WpColorManagementSurfaceV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the color management interface for a surface
Destroy the wp_color_management_surface_v1 object and do the same as unset_image_description.
pub fn set_image_description(
&self,
image_description: &WpImageDescriptionV1,
render_intent: RenderIntent,
)
pub fn set_image_description( &self, image_description: &WpImageDescriptionV1, render_intent: RenderIntent, )
set the surface image description
If this protocol object is inert, the protocol error inert is raised.
Set the image description of the underlying surface. The image description and rendering intent are double-buffered state, see wl_surface.commit.
It is the client’s responsibility to understand the image description it sets on a surface, and to provide content that matches that image description. Compositors might convert images to match their own or any other image descriptions.
Image descriptions which are not ready (see wp_image_description_v1) are forbidden in this request, and in such case the protocol error image_description is raised.
All image descriptions which are ready (see wp_image_description_v1) are allowed and must always be accepted by the compositor.
When an image description is set on a surface, it establishes an explicit link between surface pixel values and surface colorimetry. This link may be undefined for some pixel values, see the image description creator interfaces for the conditions. Non-finite floating-point values (NaN, Inf) always have an undefined colorimetry.
A rendering intent provides the client’s preference on how surface colorimetry should be mapped to each output. The render_intent value must be one advertised by the compositor with wp_color_manager_v1.render_intent event, otherwise the protocol error render_intent is raised.
By default, a surface does not have an associated image description nor a rendering intent. The handling of color on such surfaces is compositor implementation defined. Compositors should handle such surfaces as sRGB, but may handle them differently if they have specific requirements.
Setting the image description has copy semantics; after this request, the image description can be immediately destroyed without affecting the pending state of the surface.
pub fn unset_image_description(&self)
pub fn unset_image_description(&self)
remove the surface image description
If this protocol object is inert, the protocol error inert is raised.
This request removes any image description from the surface. See set_image_description for how a compositor handles a surface without an image description. This is double-buffered state, see wl_surface.commit.